@import "icon-variables/variables-beaufort.less";
@import "icon-variables/variables-time.less";
@import "icon-variables/variables-moon.less";
@import "icon-variables/variables-direction.less";
@import "icon-variables/variables-day.less";
@import "icon-variables/variables-night.less";
@import "icon-variables/variables-neutral.less";
@import "icon-variables/variables-misc.less";

