{% extends 'allianceauth/base.html' %}
{% load i18n %}

{% block page_title %}{% trans "Time Zones" %}{% endblock %}

{% block content %}
    <div class="col-lg-12">
        <h1 class="page-header text-center">{% trans "Time Zones" %}</h1>
        <div class="col-lg-12">
            {% block details %}{% endblock %}
        </div>
    </div>
{% endblock %}
